adorable
========

At this point, this library is not well documented.
This is a **beta release**.


Usage
-----

```python
import adorable

RED = adorable.color.from_name("red")
print(RED.fg("Hello adorable World"))
```

